From 181dca2c0b50af1326a84e1ec0134afab88ff5b2 Mon Sep 17 00:00:00 2001
From: Debarshi Ray <debarshir@gnome.org>
Date: Mon, 12 May 2014 14:57:18 +0200
Subject: [PATCH 1/3] Restore transparency

The transparency settings were removed as a side effect of
2bff4b63ed3ceef6055e35563e9b0b33ad57349d

This restores them and you will need a compositing window manager to
use it. The background image setting, also known as faux transparency,
was not restored.

The transparency checkbox lost its mnemonic accelerator because 't'
is already taken and using any other letter would make it hard to
restore the translations of the string.
---
 src/org.gnome.Terminal.gschema.xml | 10 +++++
 src/profile-editor.c               | 11 +++++
 src/profile-preferences.ui         | 92 ++++++++++++++++++++++++++++++++++++++
 src/terminal-schemas.h             |  3 ++
 src/terminal-screen.c              | 22 ++++++++-
 src/terminal-window.c              |  7 +++
 6 files changed, 144 insertions(+), 1 deletion(-)

diff --git a/src/org.gnome.Terminal.gschema.xml b/src/org.gnome.Terminal.gschema.xml
index 0f8433f..104e662 100644
--- a/src/org.gnome.Terminal.gschema.xml
+++ b/src/org.gnome.Terminal.gschema.xml
@@ -333,6 +333,16 @@
       <default>'narrow'</default>
       <summary>Whether ambiguous-width characters are narrow or wide when using UTF-8 encoding</summary>
     </key>
+    <key name="use-transparent-background" type="b">
+      <default>false</default>
+      <summary>Whether to use a transparent background</summary>
+    </key>
+    <key name="background-transparency-percent" type="i">
+      <default>50</default>
+      <range min="0" max="100"/>
+      <summary>Adjust the amount of transparency</summary>
+      <description>A value between 0 and 100, where 0 is opaque and 100 is fully transparent.</description>
+    </key>
   </schema>
 
   <!-- Keybinding settings -->
diff --git a/src/profile-editor.c b/src/profile-editor.c
index 3e8ccaf..f09b6bc 100644
--- a/src/profile-editor.c
+++ b/src/profile-editor.c
@@ -1106,7 +1106,18 @@ terminal_profile_edit (GSettings  *profile,
                    "active-id",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
 
+  g_settings_bind (profile, TERMINAL_PROFILE_USE_TRANSPARENT_BACKGROUND,
+                   gtk_builder_get_object (builder, "use-transparent-background"),
+                   "active", G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+  g_settings_bind (profile, TERMINAL_PROFILE_USE_TRANSPARENT_BACKGROUND,
+                   gtk_builder_get_object (builder, "background-transparent-scale-box"),
+                   "sensitive", G_SETTINGS_BIND_GET | G_SETTINGS_BIND_NO_SENSITIVITY);
+  g_settings_bind (profile, TERMINAL_PROFILE_BACKGROUND_TRANSPARENCY_PERCENT,
+                   gtk_builder_get_object (builder, "background-transparent-adjustment"),
+                   "value", G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+
   /* Finished! */
+
   terminal_util_bind_mnemonic_label_sensitivity (editor);
 
   terminal_util_dialog_focus_widget (editor, widget_name);
diff --git a/src/profile-preferences.ui b/src/profile-preferences.ui
index eb2fa26..7f8a471 100644
--- a/src/profile-preferences.ui
+++ b/src/profile-preferences.ui
@@ -23,6 +23,11 @@
     <property name="step_increment">1</property>
     <property name="page_increment">100</property>
   </object>
+  <object class="GtkAdjustment" id="background-transparent-adjustment">
+    <property name="upper">100</property>
+    <property name="step_increment">1</property>
+    <property name="page_increment">10</property>
+  </object>
   <object class="GtkListStore" id="model1">
     <columns>
       <!-- column-name gchararray -->
@@ -1045,6 +1050,93 @@
                                 <property name="position">1</property>
                               </packing>
                             </child>
+                            <child>
+                              <object class="GtkBox" id="use-transparent-background-box">
+                                <property name="visible">True</property>
+                                <property name="can_focus">False</property>
+                                <property name="orientation">horizontal</property>
+                                <property name="spacing">12</property>
+                                <child>
+                                  <object class="GtkCheckButton" id="use-transparent-background">
+                                    <property name="label" translatable="yes">Transparent background</property>
+                                    <property name="visible">True</property>
+                                    <property name="can_focus">True</property>
+                                    <property name="receives_default">False</property>
+                                    <property name="use_underline">True</property>
+                                    <property name="xalign">0</property>
+                                    <property name="draw_indicator">True</property>
+                                  </object>
+                                  <packing>
+                                    <property name="expand">False</property>
+                                    <property name="fill">False</property>
+                                    <property name="position">0</property>
+                                  </packing>
+                                </child>
+                                <child>
+                                  <object class="GtkBox" id="background-transparent-scale-box">
+                                    <property name="visible">True</property>
+                                    <property name="can_focus">False</property>
+                                    <property name="orientation">horizontal</property>
+                                    <property name="spacing">6</property>
+                                    <child>
+                                      <object class="GtkLabel" id="background-transparent-min-label">
+                                        <property name="visible">True</property>
+                                        <property name="can_focus">False</property>
+                                        <property name="xalign">0.5</property>
+                                        <property name="label" translatable="yes">none</property>
+                                        <style>
+                                          <class name="dim-label"/>
+                                        </style>
+                                      </object>
+                                      <packing>
+                                        <property name="expand">False</property>
+                                        <property name="fill">False</property>
+                                        <property name="position">0</property>
+                                      </packing>
+                                    </child>
+                                    <child>
+                                      <object class="GtkScale" id="background-transparent-scale">
+                                        <property name="visible">True</property>
+                                        <property name="can_focus">True</property>
+                                        <property name="adjustment">background-transparent-adjustment</property>
+                                        <property name="draw_value">False</property>
+                                      </object>
+                                      <packing>
+                                        <property name="expand">True</property>
+                                        <property name="fill">True</property>
+                                        <property name="position">1</property>
+                                      </packing>
+                                    </child>
+                                    <child>
+                                      <object class="GtkLabel" id="background-transparent-max-label">
+                                        <property name="visible">True</property>
+                                        <property name="can_focus">False</property>
+                                        <property name="xalign">0.5</property>
+                                        <property name="label" translatable="yes">full</property>
+                                        <style>
+                                          <class name="dim-label"/>
+                                        </style>
+                                      </object>
+                                      <packing>
+                                        <property name="expand">False</property>
+                                        <property name="fill">False</property>
+                                        <property name="position">2</property>
+                                      </packing>
+                                    </child>
+                                  </object>
+                                  <packing>
+                                    <property name="expand">True</property>
+                                    <property name="fill">True</property>
+                                    <property name="position">1</property>
+                                  </packing>
+                                </child>
+                              </object>
+                              <packing>
+                                <property name="expand">True</property>
+                                <property name="fill">True</property>
+                                <property name="position">2</property>
+                              </packing>
+                            </child>
                           </object>
                         </child>
                       </object>
diff --git a/src/terminal-schemas.h b/src/terminal-schemas.h
index 17ffdb2..0fcbf52 100644
--- a/src/terminal-schemas.h
+++ b/src/terminal-schemas.h
@@ -64,6 +64,9 @@ G_BEGIN_DECLS
 #define TERMINAL_PROFILE_VISIBLE_NAME_KEY               "visible-name"
 #define TERMINAL_PROFILE_WORD_CHAR_EXCEPTIONS_KEY       "word-char-exceptions"
 
+#define TERMINAL_PROFILE_USE_TRANSPARENT_BACKGROUND      "use-transparent-background"
+#define TERMINAL_PROFILE_BACKGROUND_TRANSPARENCY_PERCENT "background-transparency-percent"
+
 #define TERMINAL_SETTING_CONFIRM_CLOSE_KEY              "confirm-close"
 #define TERMINAL_SETTING_DEFAULT_SHOW_MENUBAR_KEY       "default-show-menubar"
 #define TERMINAL_SETTING_ENABLE_MENU_BAR_ACCEL_KEY      "menu-accelerator-enabled"
diff --git a/src/terminal-screen.c b/src/terminal-screen.c
index df3fdde..48174c2 100644
--- a/src/terminal-screen.c
+++ b/src/terminal-screen.c
@@ -750,7 +750,9 @@ terminal_screen_profile_changed_cb (GSettings     *profile,
       prop_name == I_(TERMINAL_PROFILE_BACKGROUND_COLOR_KEY) ||
       prop_name == I_(TERMINAL_PROFILE_BOLD_COLOR_SAME_AS_FG_KEY) ||
       prop_name == I_(TERMINAL_PROFILE_BOLD_COLOR_KEY) ||
-      prop_name == I_(TERMINAL_PROFILE_PALETTE_KEY))
+      prop_name == I_(TERMINAL_PROFILE_PALETTE_KEY) ||
+      prop_name == I_(TERMINAL_PROFILE_USE_TRANSPARENT_BACKGROUND) ||
+      prop_name == I_(TERMINAL_PROFILE_BACKGROUND_TRANSPARENCY_PERCENT))
     update_color_scheme (screen);
 
   if (!prop_name || prop_name == I_(TERMINAL_PROFILE_AUDIBLE_BELL_KEY))
@@ -816,6 +818,8 @@ update_color_scheme (TerminalScreen *screen)
   GdkRGBA fg, bg, bold, theme_fg, theme_bg;
   GdkRGBA *boldp;
   GtkStyleContext *context;
+  GtkWidget *toplevel;
+  gboolean transparent;
 
   context = gtk_widget_get_style_context (widget);
   gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL, &theme_fg);
@@ -836,9 +840,25 @@ update_color_scheme (TerminalScreen *screen)
     boldp = NULL;
 
   colors = terminal_g_settings_get_rgba_palette (priv->profile, TERMINAL_PROFILE_PALETTE_KEY, &n_colors);
+
+  transparent = g_settings_get_boolean (profile, TERMINAL_PROFILE_USE_TRANSPARENT_BACKGROUND);
+  if (transparent)
+    {
+      gint transparency_percent;
+
+      transparency_percent = g_settings_get_int (profile, TERMINAL_PROFILE_BACKGROUND_TRANSPARENCY_PERCENT);
+      bg.alpha = (100 - transparency_percent) / 100.0;
+    }
+  else
+    bg.alpha = 1.0;
+
   vte_terminal_set_colors (VTE_TERMINAL (screen), &fg, &bg,
                            colors, n_colors);
   vte_terminal_set_color_bold (VTE_TERMINAL (screen), boldp);
+
+  toplevel = gtk_widget_get_toplevel (GTK_WIDGET (screen));
+  if (toplevel != NULL && gtk_widget_is_toplevel (toplevel))
+    gtk_widget_set_app_paintable (toplevel, transparent);
 }
 
 static void
diff --git a/src/terminal-window.c b/src/terminal-window.c
index 12cae4f..366e4f8 100644
--- a/src/terminal-window.c
+++ b/src/terminal-window.c
@@ -2549,6 +2549,8 @@ terminal_window_init (TerminalWindow *window)
   TerminalWindowPrivate *priv;
   TerminalApp *app;
   TerminalSettingsList *profiles_list;
+  GdkScreen *screen;
+  GdkVisual *visual;
   GtkActionGroup *action_group;
   GtkAction *action;
   GtkUIManager *manager;
@@ -2564,6 +2566,11 @@ terminal_window_init (TerminalWindow *window)
 
   gtk_widget_init_template (GTK_WIDGET (window));
 
+  screen = gtk_widget_get_screen (GTK_WIDGET (window));
+  visual = gdk_screen_get_rgba_visual (screen);
+  if (visual != NULL)
+    gtk_widget_set_visual (GTK_WIDGET (window), visual);
+
   uuid_generate (u);
   uuid_unparse (u, uuidstr);
   priv->uuid = g_strdup (uuidstr);
-- 
2.1.0


From de7d64698ac700f63898221a5815af939001ba18 Mon Sep 17 00:00:00 2001
From: Lars Uebernickel <lars.uebernickel@canonical.com>
Date: Wed, 28 May 2014 14:11:02 +0200
Subject: [PATCH 2/3] window: Make the drawing robust across all themes

There are lots of themes out there in the wild that do not specify a
background-color for all widgets and the default is transparent. This
is usually not a problem because GTK+ sets an opaque region on the
whole window and things without a background-color get drawn with the
theme's default background colour. However, to achieve transparency
we disable the opaque region by making the window app-paintable. This
can lead to transparent menubars or notebook tabs in some themes. We
can avoid this by ensuring that the window always renders a background.

https://bugzilla.gnome.org/show_bug.cgi?id=730016
---
 src/terminal-window.c | 21 +++++++++++++++++++++
 1 file changed, 21 insertions(+)

diff --git a/src/terminal-window.c b/src/terminal-window.c
index 366e4f8..2458656 100644
--- a/src/terminal-window.c
+++ b/src/terminal-window.c
@@ -2189,6 +2189,26 @@ terminal_window_realize (GtkWidget *widget)
 }
 
 static gboolean
+terminal_window_draw (GtkWidget *widget,
+                      cairo_t   *cr)
+{
+  if (gtk_widget_get_app_paintable (widget))
+    {
+      GtkStyleContext *context;
+      int width;
+      int height;
+
+      context = gtk_widget_get_style_context (widget);
+      width = gtk_widget_get_allocated_width (widget);
+      height = gtk_widget_get_allocated_height (widget);
+      gtk_render_background (context, cr, 0, 0, width, height);
+      gtk_render_frame (context, cr, 0, 0, width, height);
+    }
+
+  return GTK_WIDGET_CLASS (terminal_window_parent_class)->draw (widget, cr);
+}
+
+static gboolean
 terminal_window_state_event (GtkWidget            *widget,
                              GdkEventWindowState  *event)
 {
@@ -2753,6 +2773,7 @@ terminal_window_class_init (TerminalWindowClass *klass)
 
   widget_class->show = terminal_window_show;
   widget_class->realize = terminal_window_realize;
+  widget_class->draw = terminal_window_draw;
   widget_class->window_state_event = terminal_window_state_event;
   widget_class->screen_changed = terminal_window_screen_changed;
   widget_class->style_updated = terminal_window_style_updated;
-- 
2.1.0


From dfc31fb0803d546cc21ef8bcd33e54c30e14dc1c Mon Sep 17 00:00:00 2001
From: Debarshi Ray <debarshir@gnome.org>
Date: Tue, 17 Feb 2015 17:06:17 +0100
Subject: [PATCH 3/3] Restore translations for transparency

---
 po/am.po          | 4 ++--
 po/ar.po          | 4 ++--
 po/as.po          | 4 ++--
 po/ast.po         | 4 ++--
 po/az.po          | 4 ++--
 po/be.po          | 3 +++
 po/be@latin.po    | 4 ++--
 po/bg.po          | 3 +++
 po/bn_IN.po       | 3 +++
 po/bs.po          | 4 ++++
 po/ca.po          | 3 +++
 po/ca@valencia.po | 3 +++
 po/cs.po          | 3 +++
 po/cy.po          | 4 ++--
 po/da.po          | 4 ++--
 po/de.po          | 4 ++--
 po/dz.po          | 4 ++--
 po/el.po          | 3 +++
 po/en@shaw.po     | 4 ++--
 po/en_CA.po       | 4 ++--
 po/en_GB.po       | 4 ++--
 po/es.po          | 4 ++--
 po/et.po          | 3 +++
 po/eu.po          | 4 ++--
 po/fa.po          | 3 +++
 po/fi.po          | 5 ++++-
 po/fr.po          | 3 +++
 po/fur.po         | 4 ++--
 po/ga.po          | 3 +++
 po/gl.po          | 4 ++--
 po/gu.po          | 4 ++--
 po/he.po          | 4 ++--
 po/hi.po          | 4 ++--
 po/hr.po          | 4 ++--
 po/hu.po          | 3 +++
 po/hy.po          | 4 ++--
 po/id.po          | 3 +++
 po/it.po          | 3 +++
 po/ja.po          | 3 +++
 po/ka.po          | 2 +-
 po/kk.po          | 3 +++
 po/kn.po          | 3 +++
 po/ko.po          | 3 +++
 po/ku.po          | 4 ++--
 po/lt.po          | 3 +++
 po/lv.po          | 4 ++--
 po/mai.po         | 4 ++--
 po/mg.po          | 4 ++--
 po/mk.po          | 4 ++--
 po/ml.po          | 4 ++--
 po/mn.po          | 4 ++--
 po/mr.po          | 4 ++--
 po/ms.po          | 4 ++--
 po/nb.po          | 3 +++
 po/nds.po         | 4 ++--
 po/ne.po          | 4 ++--
 po/nl.po          | 3 +++
 po/nn.po          | 4 ++--
 po/oc.po          | 4 ++--
 po/or.po          | 4 ++--
 po/pa.po          | 4 ++--
 po/pl.po          | 3 +++
 po/ps.po          | 4 ++--
 po/pt.po          | 4 ++--
 po/pt_BR.po       | 3 +++
 po/ro.po          | 4 ++--
 po/ru.po          | 3 +++
 po/rw.po          | 2 +-
 po/si.po          | 4 ++--
 po/sk.po          | 3 +++
 po/sl.po          | 3 +++
 po/sq.po          | 4 ++--
 po/sr.po          | 3 +++
 po/sr@latin.po    | 3 +++
 po/sv.po          | 3 +++
 po/ta.po          | 4 ++--
 po/te.po          | 4 ++--
 po/th.po          | 4 ++--
 po/tr.po          | 3 +++
 po/ug.po          | 4 ++--
 po/uk.po          | 4 ++--
 po/vi.po          | 3 +++
 po/wa.po          | 4 ++--
 po/xh.po          | 4 ++--
 po/zh_CN.po       | 3 +++
 po/zh_HK.po       | 3 +++
 po/zh_TW.po       | 3 +++
 87 files changed, 210 insertions(+), 101 deletions(-)

diff --git a/po/am.po b/po/am.po
index 27a7e96..04a8ad9 100644
--- a/po/am.po
+++ b/po/am.po
@@ -613,8 +613,8 @@ msgid "_Text color:"
 msgstr "የ_ጽሑፍ ቀለም፦"
 
 #: ../src/gnome-terminal.glade2.h:102
-msgid "_Transparent background"
-msgstr "_የሚያሳይ መደብ"
+msgid "Transparent background"
+msgstr "የሚያሳይ መደብ"
 
 #: ../src/gnome-terminal.glade2.h:103
 msgid "_Update login records when command is launched"
diff --git a/po/ar.po b/po/ar.po
index c27cd9c..f541938 100644
--- a/po/ar.po
+++ b/po/ar.po
@@ -2914,8 +2914,8 @@ msgstr "أغ_لق النافذة"
 #~ msgid "Background image _scrolls"
 #~ msgstr "صورة الخلفية ت_لتف"
 
-#~ msgid "_Transparent background"
-#~ msgstr "خلفية _شفافة"
+msgid "Transparent background"
+msgstr "خلفية شفافة"
 
 #~ msgid "S_hade transparent or image background:"
 #~ msgstr "_ظلل شفافية أو صورة الخلفية:"
diff --git a/po/as.po b/po/as.po
index 0bd699d..63fca01 100644
--- a/po/as.po
+++ b/po/as.po
@@ -2979,8 +2979,8 @@ msgstr "উইন্ডো বন্ধ কৰক (_l)"
 #~ msgid "Background image _scrolls"
 #~ msgstr "পটভূমিৰ ছবি স্ক্ৰল কৰক (_s)"
 
-#~ msgid "_Transparent background"
-#~ msgstr "স্বচ্চ পটভূমি (_T)"
+msgid "Transparent background"
+msgstr "স্বচ্চ পটভূমি "
 
 #~ msgid "S_hade transparent or image background:"
 #~ msgstr "স্বচ্ছ বা ছবিৰ সৈতে পটভূমি ছায়া আচ্ছন্ন কৰক (_h):"
diff --git a/po/ast.po b/po/ast.po
index d1c6e7b..4210820 100644
--- a/po/ast.po
+++ b/po/ast.po
@@ -1598,8 +1598,8 @@ msgid "_Text color:"
 msgstr "Color del _testu:"
 
 #: ../src/profile-preferences.glade.h:77
-msgid "_Transparent background"
-msgstr "Fondu _tresparente"
+msgid "Transparent background"
+msgstr "Fondu tresparente"
 
 #: ../src/profile-preferences.glade.h:78
 msgid "_Underline color:"
diff --git a/po/az.po b/po/az.po
index b0f2e3e..877f114 100644
--- a/po/az.po
+++ b/po/az.po
@@ -619,8 +619,8 @@ msgid "_Text color:"
 msgstr "_Mətn rəngi:"
 
 #: ../src/gnome-terminal.glade2.h:102
-msgid "_Transparent background"
-msgstr "_Şəffaf arxa plan"
+msgid "Transparent background"
+msgstr "Şəffaf arxa plan"
 
 #: ../src/gnome-terminal.glade2.h:103
 msgid "_Update login records when command is launched"
diff --git a/po/be.po b/po/be.po
index fca0ae4..74ff329 100644
--- a/po/be.po
+++ b/po/be.po
@@ -2015,3 +2015,6 @@ msgstr ""
 msgid "C_lose Window"
 msgstr "_Закрыць акно"
 
+msgid "Transparent background"
+msgstr "Празрысты фон"
+
diff --git a/po/be@latin.po b/po/be@latin.po
index 1e057c7..1d22a58 100644
--- a/po/be@latin.po
+++ b/po/be@latin.po
@@ -1425,8 +1425,8 @@ msgid "_Text color:"
 msgstr "Koler _tekstu:"
 
 #: ../src/profile-preferences.glade.h:73
-msgid "_Transparent background"
-msgstr "_Prazrysty fon"
+msgid "Transparent background"
+msgstr "Prazrysty fon"
 
 #: ../src/profile-preferences.glade.h:74
 msgid "_Update login records when command is launched"
diff --git a/po/bg.po b/po/bg.po
index 7e9c9be..241ef52 100644
--- a/po/bg.po
+++ b/po/bg.po
@@ -2100,3 +2100,6 @@ msgstr ""
 #: ../src/terminal-window.c:3652
 msgid "C_lose Window"
 msgstr "_Затваряне на този прозорец"
+
+msgid "Transparent background"
+msgstr "Прозрачен фон"
diff --git a/po/bn_IN.po b/po/bn_IN.po
index c74246a..d65b322 100644
--- a/po/bn_IN.po
+++ b/po/bn_IN.po
@@ -2358,3 +2358,6 @@ msgstr "উইন্ডো বন্ধ করুন (_l)"
 
 #~ msgid "_Title:"
 #~ msgstr "শিরোনাম: (_T)"
+
+msgid "Transparent background"
+msgstr "স্বচ্চ পটভূমি "
diff --git a/po/bs.po b/po/bs.po
index 49e7108..fccfa86 100644
--- a/po/bs.po
+++ b/po/bs.po
@@ -680,6 +680,10 @@ msgstr "Kratica tastature za povećavanje fonta"
 msgid "Keyboard shortcut to make font smaller"
 msgstr "Kratica tastature za smanjivanje fonta"
 
+#: ../src/gnome-terminal.glade2.h:102
+msgid "Transparent background"
+msgstr "Providna pozadina"
+
 #: ../src/org.gnome.Terminal.gschema.xml.h:78
 msgid "Keyboard shortcut to make font normal-size"
 msgstr "Kratica tastature za postavljanje fonta na normalnu veličinu"
diff --git a/po/ca.po b/po/ca.po
index 567b344..156eed1 100644
--- a/po/ca.po
+++ b/po/ca.po
@@ -2111,3 +2111,6 @@ msgstr "Tanca la _finestra"
 
 #~ msgid "Use _dark theme variant"
 #~ msgstr "Utilitza la variant de tema _fosc"
+
+msgid "Transparent background"
+msgstr "Fons transparent"
diff --git a/po/ca@valencia.po b/po/ca@valencia.po
index 1c279a0..4073f71 100644
--- a/po/ca@valencia.po
+++ b/po/ca@valencia.po
@@ -2092,3 +2092,6 @@ msgstr ""
 #: ../src/terminal-window.c:3645
 msgid "C_lose Window"
 msgstr "Tanca la _finestra"
+
+msgid "Transparent background"
+msgstr "Fons transparent"
diff --git a/po/cs.po b/po/cs.po
index f1e8c44..912b4df 100644
--- a/po/cs.po
+++ b/po/cs.po
@@ -2063,3 +2063,6 @@ msgstr ""
 #: ../src/terminal-window.c:3652
 msgid "C_lose Window"
 msgstr "_Zavřít okno"
+
+msgid "Transparent background"
+msgstr "Průsvitné pozadí"
diff --git a/po/cy.po b/po/cy.po
index 06d0e3c..2491bd1 100644
--- a/po/cy.po
+++ b/po/cy.po
@@ -1447,8 +1447,8 @@ msgid "_Text color:"
 msgstr "Lliw'r _testun:"
 
 #: ../src/profile-preferences.glade.h:73
-msgid "_Transparent background"
-msgstr "Cefndir _tryloyw"
+msgid "Transparent background"
+msgstr "Cefndir tryloyw"
 
 #: ../src/profile-preferences.glade.h:74
 msgid "_Update login records when command is launched"
diff --git a/po/da.po b/po/da.po
index 74b7d0b..af69a6b 100644
--- a/po/da.po
+++ b/po/da.po
@@ -2987,8 +2987,8 @@ msgstr "_Luk vindue"
 #~ msgid "_Solid color"
 #~ msgstr "_Ensfarvet"
 
-#~ msgid "_Transparent background"
-#~ msgstr "_Gennemsigtig baggrund"
+msgid "Transparent background"
+msgstr "Gennemsigtig baggrund"
 
 #~ msgid ""
 #~ "You already have a profile called “%s”. Do you want to create another "
diff --git a/po/de.po b/po/de.po
index 6b2bb19..2b814c0 100644
--- a/po/de.po
+++ b/po/de.po
@@ -3060,8 +3060,8 @@ msgstr "Fenster _schließen"
 #~ msgid "Background image _scrolls"
 #~ msgstr "Hintergrundbild _folgt Bildlauf"
 
-#~ msgid "_Transparent background"
-#~ msgstr "_Transparenter Hintergrund"
+msgid "Transparent background"
+msgstr "Transparenter Hintergrund"
 
 #~ msgid "S_hade transparent or image background:"
 #~ msgstr "Transparenz und Bildhintergründe _abdunkeln:"
diff --git a/po/dz.po b/po/dz.po
index ecb8fd5..290934a 100644
--- a/po/dz.po
+++ b/po/dz.po
@@ -1551,8 +1551,8 @@ msgid "_Text color:"
 msgstr "ཚིག་ཡིག་ཚོས་གཞི་:(_T)"
 
 #: ../src/profile-preferences.glade.h:77
-msgid "_Transparent background"
-msgstr "དྭངས་གསལ་རྒྱབ་གཞི།(_T)"
+msgid "Transparent background"
+msgstr "དྭངས་གསལ་རྒྱབ་གཞི།"
 
 #: ../src/profile-preferences.glade.h:78
 #, fuzzy
diff --git a/po/el.po b/po/el.po
index b81802c..a32ae26 100644
--- a/po/el.po
+++ b/po/el.po
@@ -2289,3 +2289,6 @@ msgstr "Κ_λείσιμο παραθύρου"
 
 #~ msgid "_Input Methods"
 #~ msgstr "_Μέθοδοι εισαγωγής"
+
+msgid "Transparent background"
+msgstr "Διάφανο παρασκήνιο"
diff --git a/po/en@shaw.po b/po/en@shaw.po
index 65f3d41..05dc99d 100644
--- a/po/en@shaw.po
+++ b/po/en@shaw.po
@@ -1467,8 +1467,8 @@ msgid "_Text color:"
 msgstr "_𐑑𐑧𐑒𐑕𐑑 𐑒𐑳𐑤𐑼:"
 
 #: ../src/profile-preferences.glade.h:78
-msgid "_Transparent background"
-msgstr "_𐑑𐑮𐑨𐑯𐑕𐑐𐑸𐑩𐑯𐑑 𐑚𐑨𐑒𐑜𐑮𐑬𐑯𐑛"
+msgid "Transparent background"
+msgstr "𐑑𐑮𐑨𐑯𐑕𐑐𐑸𐑩𐑯𐑑 𐑚𐑨𐑒𐑜𐑮𐑬𐑯𐑛"
 
 #: ../src/profile-preferences.glade.h:79
 msgid "_Underline color:"
diff --git a/po/en_CA.po b/po/en_CA.po
index c79cbf5..b8b14d2 100644
--- a/po/en_CA.po
+++ b/po/en_CA.po
@@ -556,8 +556,8 @@ msgid "_Text color:"
 msgstr "_Text colour:"
 
 #: ../src/gnome-terminal.glade2.h:86
-msgid "_Transparent background"
-msgstr "_Transparent background"
+msgid "Transparent background"
+msgstr "Transparent background"
 
 #: ../src/gnome-terminal.glade2.h:87
 msgid "_Update login records when command is launched"
diff --git a/po/en_GB.po b/po/en_GB.po
index 4d38486..69e7113 100644
--- a/po/en_GB.po
+++ b/po/en_GB.po
@@ -2732,8 +2732,8 @@ msgstr "_Title:"
 #~ msgid "Background image _scrolls"
 #~ msgstr "Background image _scrolls"
 
-#~ msgid "_Transparent background"
-#~ msgstr "_Transparent background"
+msgid "Transparent background"
+msgstr "Transparent background"
 
 #~ msgid "S_hade transparent or image background:"
 #~ msgstr "S_hade transparent or image background:"
diff --git a/po/es.po b/po/es.po
index c8b47fe..4d33066 100644
--- a/po/es.po
+++ b/po/es.po
@@ -3095,8 +3095,8 @@ msgstr "_Cerrar ventana"
 #~ msgid "_Solid color"
 #~ msgstr "Color _sólido"
 
-#~ msgid "_Transparent background"
-#~ msgstr "Fondo _transparente"
+msgid "Transparent background"
+msgstr "Fondo transparente"
 
 #~ msgid "No such profile \"%s\", using default profile\n"
 #~ msgstr "No existe el perfil «%s», usando el perfil predeterminado\n"
diff --git a/po/et.po b/po/et.po
index 4b1c2a7..7707611 100644
--- a/po/et.po
+++ b/po/et.po
@@ -1747,3 +1747,6 @@ msgstr "Su_lge aken"
 
 #~ msgid "Choose base profile"
 #~ msgstr "Vali põhiprofiil"
+
+msgid "Transparent background"
+msgstr "Läbipaistev taust"
diff --git a/po/eu.po b/po/eu.po
index 97bb976..b53f33c 100644
--- a/po/eu.po
+++ b/po/eu.po
@@ -2972,8 +2972,8 @@ msgstr "It_xi leihoa"
 #~ msgid "_Solid color"
 #~ msgstr "_Kolore solidoa"
 
-#~ msgid "_Transparent background"
-#~ msgstr "_Atzeko plano gardena"
+msgid "Transparent background"
+msgstr "Atzeko plano gardena"
 
 #~ msgid ""
 #~ "You already have a profile called “%s”. Do you want to create another "
diff --git a/po/fa.po b/po/fa.po
index 2090863..b9a05af 100644
--- a/po/fa.po
+++ b/po/fa.po
@@ -2027,3 +2027,6 @@ msgstr "ذخیره به نام..."
 #: ../src/terminal-window.c:3456
 msgid "_Title:"
 msgstr "_عنوان:"
+
+msgid "Transparent background"
+msgstr "پس‌زمینه‌ی شفاف"
diff --git a/po/fi.po b/po/fi.po
index f80a962..dacd609 100644
--- a/po/fi.po
+++ b/po/fi.po
@@ -2069,6 +2069,9 @@ msgstr ""
 msgid "C_lose Window"
 msgstr "_Sulje ikkuna"
 
+msgid "Transparent background"
+msgstr "Läpinäkyvä tausta"
+
 #~ msgid "Set the terminal title"
 #~ msgstr "Aseta päätteen otsikko"
 
@@ -2083,4 +2086,4 @@ msgstr "_Sulje ikkuna"
 #~ msgstr "Käytetäänkö teeman tummaan muunnelmaa"
 
 #~ msgid "Use _dark theme variant"
-#~ msgstr "Käytä _teeman tummaa muunnelmaa"
+#~ msgstr "Käytä _teeman tummaa muunnelmaa"
\ No newline at end of file
diff --git a/po/fr.po b/po/fr.po
index fd28f38..babd28d 100644
--- a/po/fr.po
+++ b/po/fr.po
@@ -2135,3 +2135,6 @@ msgstr "Fermer _la fenêtre"
 
 #~ msgid "Use _dark theme variant"
 #~ msgstr "Utiliser une variante de thème _foncée"
+
+msgid "Transparent background"
+msgstr "Arrière-plan transparent"
diff --git a/po/fur.po b/po/fur.po
index 5a20170..8c3daaf 100644
--- a/po/fur.po
+++ b/po/fur.po
@@ -580,8 +580,8 @@ msgid "_Text color:"
 msgstr "Colôr dal _test:"
 
 #: ../src/gnome-terminal.glade2.h:86
-msgid "_Transparent background"
-msgstr "Fondâl _trasparent"
+msgid "Transparent background"
+msgstr "Fondâl trasparent"
 
 #: ../src/gnome-terminal.glade2.h:87
 msgid "_Update login records when command is launched"
diff --git a/po/ga.po b/po/ga.po
index 93d5fa9..feb87dc 100644
--- a/po/ga.po
+++ b/po/ga.po
@@ -1925,3 +1925,6 @@ msgstr "_Dún Fuinneog"
 #: ../src/terminal-window.c:3582
 msgid "C_lose Terminal"
 msgstr "_Dún Teirminéal"
+
+msgid "Transparent background"
+msgstr "Cúlra trédhearcach"
diff --git a/po/gl.po b/po/gl.po
index 1429c66..6820190 100644
--- a/po/gl.po
+++ b/po/gl.po
@@ -3055,8 +3055,8 @@ msgstr "P_echar a xanela"
 #~ msgid "Background image _scrolls"
 #~ msgstr "A imaxe de fondo _desprázase"
 
-#~ msgid "_Transparent background"
-#~ msgstr "Fondo _transparente"
+msgid "Transparent background"
+msgstr "Fondo transparente"
 
 #~ msgid "S_hade transparent or image background:"
 #~ msgstr "_Sombra transparente ou imaxe de fondo:"
diff --git a/po/gu.po b/po/gu.po
index 0bcb195..f72a807 100644
--- a/po/gu.po
+++ b/po/gu.po
@@ -2944,8 +2944,8 @@ msgstr "વિન્ડો બંધ કરો (_l)"
 #~ msgid "_Solid color"
 #~ msgstr "ઘટ્ટ રંગ (_S)"
 
-#~ msgid "_Transparent background"
-#~ msgstr "પારદર્શક પાશ્વ ભાગનો ભાગ (_T)"
+msgid "Transparent background"
+msgstr "પારદર્શક પાશ્વ ભાગનો ભાગ"
 
 #~ msgid "No such profile \"%s\", using default profile\n"
 #~ msgstr "\"%s\" જેવી કોઈ રૂપરેખા નથી, મૂળભૂત રૂપરેખા વાપરી રહ્યા છે\n"
diff --git a/po/he.po b/po/he.po
index 0d9dfe0..ff4cc33 100644
--- a/po/he.po
+++ b/po/he.po
@@ -3007,8 +3007,8 @@ msgstr "סגירת ה_חלון"
 #~ msgid "_Solid color"
 #~ msgstr "צבע _אחיד"
 
-#~ msgid "_Transparent background"
-#~ msgstr "רקע _שקוף"
+msgid "Transparent background"
+msgstr "רקע שקוף"
 
 #~ msgid "No such profile \"%s\", using default profile\n"
 #~ msgstr "No such profile \"%s\", using default profile\n"
diff --git a/po/hi.po b/po/hi.po
index 2d7dc5b..adf8d35 100644
--- a/po/hi.po
+++ b/po/hi.po
@@ -2979,8 +2979,8 @@ msgstr "विंडो बंद करें (_l)"
 #~ msgid "_Background image"
 #~ msgstr "पृष्ठभूमि छवि (_B)"
 
-#~ msgid "_Transparent background"
-#~ msgstr "पारदर्शी पृष्ठभूमि (_T)"
+msgid "Transparent background"
+msgstr "पारदर्शी पृष्ठभूमि"
 
 #~ msgid "S/Key Challenge Response"
 #~ msgstr "एस/कुंजी चैलेंज प्रतिक्रिया"
diff --git a/po/hr.po b/po/hr.po
index cb48c52..747cf48 100644
--- a/po/hr.po
+++ b/po/hr.po
@@ -1362,8 +1362,8 @@ msgid "_Text color:"
 msgstr "_Boja teksta:"
 
 #: ../src/profile-preferences.glade.h:69
-msgid "_Transparent background"
-msgstr "_Prozirna pozadina"
+msgid "Transparent background"
+msgstr "Prozirna pozadina"
 
 #: ../src/profile-preferences.glade.h:70
 msgid "_Update login records when command is launched"
diff --git a/po/hu.po b/po/hu.po
index ad585ef..b9a481b 100644
--- a/po/hu.po
+++ b/po/hu.po
@@ -2509,3 +2509,6 @@ msgstr "_Ablak bezárása"
 
 #~ msgid "Background type"
 #~ msgstr "Háttér típusa"
+
+msgid "Transparent background"
+msgstr "Áttetsző háttér"
diff --git a/po/hy.po b/po/hy.po
index 5584901..caadbba 100644
--- a/po/hy.po
+++ b/po/hy.po
@@ -1011,8 +1011,8 @@ msgid "_Text color:"
 msgstr "_Տեքստի գույնը՝"
 
 #: ../src/profile-preferences.glade.h:73
-msgid "_Transparent background"
-msgstr "_Թափանցիկ նախադրյալ"
+msgid "Transparent background"
+msgstr "Թափանցիկ նախադրյալ"
 
 #: ../src/profile-preferences.glade.h:74
 msgid "_Update login records when command is launched"
diff --git a/po/id.po b/po/id.po
index 346b5d8..2448444 100644
--- a/po/id.po
+++ b/po/id.po
@@ -2068,3 +2068,6 @@ msgstr ""
 #: ../src/terminal-window.c:3652
 msgid "C_lose Window"
 msgstr "Tutup Jende_la"
+
+msgid "Transparent background"
+msgstr "Latar belakang transparan"
diff --git a/po/it.po b/po/it.po
index 5a1847f..2eb1d62 100644
--- a/po/it.po
+++ b/po/it.po
@@ -2093,3 +2093,6 @@ msgstr ""
 #: ../src/terminal-window.c:3652
 msgid "C_lose Window"
 msgstr "Chiudi _finestra"
+
+msgid "Transparent background"
+msgstr "Sfondo trasparente"
diff --git a/po/ja.po b/po/ja.po
index 4f8f4de..ce2ec95 100644
--- a/po/ja.po
+++ b/po/ja.po
@@ -1902,3 +1902,6 @@ msgstr "この端末には未だ実行中のプロセスが存在しています
 #: ../src/terminal-window.c:3652
 msgid "C_lose Window"
 msgstr "ウィンドウを閉じる(_L)"
+
+msgid "Transparent background"
+msgstr "透過な画像にする"
diff --git a/po/ka.po b/po/ka.po
index 8415e88..3717b7e 100644
--- a/po/ka.po
+++ b/po/ka.po
@@ -568,7 +568,7 @@ msgstr "_ტექსტის ფერი:"
 
 #: ../src/gnome-terminal.glade2.h:86
 #, fuzzy
-msgid "_Transparent background"
+msgid "Transparent background"
 msgstr "გამჭირვალე"
 
 #: ../src/gnome-terminal.glade2.h:87
diff --git a/po/kk.po b/po/kk.po
index dba7503..f7ac993 100644
--- a/po/kk.po
+++ b/po/kk.po
@@ -2030,3 +2030,6 @@ msgstr "Терезені жа_бу"
 
 #~ msgid "Be quiet"
 #~ msgstr "Тыныш болу"
+
+msgid "Transparent background"
+msgstr "Мөлдір фон"
diff --git a/po/kn.po b/po/kn.po
index c887f88..e899ef3 100644
--- a/po/kn.po
+++ b/po/kn.po
@@ -2344,3 +2344,6 @@ msgstr "ಕಿಟಕಿಯನ್ನು ಮುಚ್ಚು  (_l)"
 
 #~ msgid "_Title:"
 #~ msgstr "ಶೀರ್ಷಿಕೆ(_T):"
+
+msgid "Transparent background"
+msgstr "ಪಾರದರ್ಶಕ ಹಿನ್ನಲೆ"
diff --git a/po/ko.po b/po/ko.po
index 0700e25..912e940 100644
--- a/po/ko.po
+++ b/po/ko.po
@@ -2078,3 +2078,6 @@ msgstr "창 닫기(_L)"
 
 #~ msgid "Use _dark theme variant"
 #~ msgstr "어두운 테마 사용(_D)"
+
+msgid "Transparent background"
+msgstr "투명한 배경"
diff --git a/po/ku.po b/po/ku.po
index 221825b..96e3581 100644
--- a/po/ku.po
+++ b/po/ku.po
@@ -557,8 +557,8 @@ msgid "_Text color:"
 msgstr "Rengê _nivîsê:"
 
 #: ../src/gnome-terminal.glade2.h:86
-msgid "_Transparent background"
-msgstr "Rûerdê _transparan"
+msgid "Transparent background"
+msgstr "Rûerdê transparan"
 
 #: ../src/gnome-terminal.glade2.h:87
 msgid "_Update login records when command is launched"
diff --git a/po/lt.po b/po/lt.po
index 294482b..c0ec0cf 100644
--- a/po/lt.po
+++ b/po/lt.po
@@ -2082,3 +2082,6 @@ msgstr "_Užverti langą"
 
 #~ msgid "Use _dark theme variant"
 #~ msgstr "Nau_doti tamsų temos variantą"
+
+msgid "Transparent background"
+msgstr "Permatomas fonas"
diff --git a/po/lv.po b/po/lv.po
index a50f529..b29541f 100644
--- a/po/lv.po
+++ b/po/lv.po
@@ -3016,8 +3016,8 @@ msgstr "Aizvērt _logu"
 #~ msgid "Background image _scrolls"
 #~ msgstr "Fona attēla ritināšanā_s"
 
-#~ msgid "_Transparent background"
-#~ msgstr "_Caurspīdīgs fons"
+msgid "Transparent background"
+msgstr "Caurspīdīgs fons"
 
 #~ msgid "S_hade transparent or image background:"
 #~ msgstr "_Aizēnot caurspīdīgo vai attēla fonu:"
diff --git a/po/mai.po b/po/mai.po
index 9b984a0..a3c0e17 100644
--- a/po/mai.po
+++ b/po/mai.po
@@ -1290,8 +1290,8 @@ msgid "_Text color:"
 msgstr "पाठ रँग (_T):"
 
 #: ../src/profile-preferences.glade.h:69
-msgid "_Transparent background"
-msgstr "पारदर्शी पृष्ठभूमि (_T)"
+msgid "Transparent background"
+msgstr "पारदर्शी पृष्ठभूमि"
 
 #: ../src/profile-preferences.glade.h:70
 msgid "_Update login records when command is launched"
diff --git a/po/mg.po b/po/mg.po
index 1c1895c..a805417 100644
--- a/po/mg.po
+++ b/po/mg.po
@@ -566,8 +566,8 @@ msgid "_Text color:"
 msgstr "Lokon'ny _soratra:"
 
 #: ../src/gnome-terminal.glade2.h:86
-msgid "_Transparent background"
-msgstr "_Afara tatera-pahazavana"
+msgid "Transparent background"
+msgstr "Afara tatera-pahazavana"
 
 #: ../src/gnome-terminal.glade2.h:87
 msgid "_Update login records when command is launched"
diff --git a/po/mk.po b/po/mk.po
index e31378a..d2b74d4 100644
--- a/po/mk.po
+++ b/po/mk.po
@@ -1166,8 +1166,8 @@ msgid "_Text color:"
 msgstr "_Боја на текстот:"
 
 #: ../src/profile-preferences.glade.h:77
-msgid "_Transparent background"
-msgstr "_Транспарентна позадина"
+msgid "Transparent background"
+msgstr "Транспарентна позадина"
 
 #: ../src/profile-preferences.glade.h:78
 #| msgid "_Text color:"
diff --git a/po/ml.po b/po/ml.po
index cc1928d..62abd21 100644
--- a/po/ml.po
+++ b/po/ml.po
@@ -2751,8 +2751,8 @@ msgstr "ടെര്‍മിനല്‍ അ_ടയ്ക്കുക"
 #~ msgid "_Solid color"
 #~ msgstr "_സോളിഡ് നിറം"
 
-#~ msgid "_Transparent background"
-#~ msgstr "_പുറകിലുള്ളവ കാണാവുന്ന പശ്ചാത്തലം"
+msgid "Transparent background"
+msgstr "പുറകിലുള്ളവ കാണാവുന്ന പശ്ചാത്തലം"
 
 #~ msgid "S/Key Challenge Response"
 #~ msgstr "S/Key ചാലഞ്ച് മറുപടി"
diff --git a/po/mn.po b/po/mn.po
index 4922041..9696b7f 100644
--- a/po/mn.po
+++ b/po/mn.po
@@ -617,8 +617,8 @@ msgid "_Text color:"
 msgstr "_Текстийн өнгө:"
 
 #: ../src/gnome-terminal.glade2.h:102
-msgid "_Transparent background"
-msgstr "_Тунгалаг дэвсгэр"
+msgid "Transparent background"
+msgstr "Тунгалаг дэвсгэр"
 
 #: ../src/gnome-terminal.glade2.h:103
 msgid "_Update login records when command is launched"
diff --git a/po/mr.po b/po/mr.po
index 61997da..50451d7 100644
--- a/po/mr.po
+++ b/po/mr.po
@@ -3015,8 +3015,8 @@ msgstr "चौकट बंद करा (_l)"
 #~ msgid "_Solid color"
 #~ msgstr "गडद रंग (_S)"
 
-#~ msgid "_Transparent background"
-#~ msgstr "पारदर्शी पार्श्वभूमी(_T)"
+msgid "Transparent background"
+msgstr "पारदर्शी पार्श्वभूमी"
 
 #~ msgid "Disabled"
 #~ msgstr "अकार्यान्वीतित"
diff --git a/po/ms.po b/po/ms.po
index 5b663aa..38a2afe 100644
--- a/po/ms.po
+++ b/po/ms.po
@@ -630,8 +630,8 @@ msgid "_Text color:"
 msgstr "Warna _Teks:"
 
 #: ../src/gnome-terminal.glade2.h:102
-msgid "_Transparent background"
-msgstr "LatarBelakang _Telus"
+msgid "Transparent background"
+msgstr "LatarBelakang Telus"
 
 #: ../src/gnome-terminal.glade2.h:103
 msgid "_Update login records when command is launched"
diff --git a/po/nb.po b/po/nb.po
index c14ae58..f5a590e 100644
--- a/po/nb.po
+++ b/po/nb.po
@@ -2054,3 +2054,6 @@ msgstr ""
 #: ../src/terminal-window.c:3652
 msgid "C_lose Window"
 msgstr "_Lukk vindu"
+
+msgid "Transparent background"
+msgstr "Gjennomsiktig bakgrunn"
diff --git a/po/nds.po b/po/nds.po
index 98a1287..94fd757 100644
--- a/po/nds.po
+++ b/po/nds.po
@@ -995,8 +995,8 @@ msgid "_Text color:"
 msgstr "_Textklöör:"
 
 #: ../src/profile-preferences.glade.h:73
-msgid "_Transparent background"
-msgstr "_Döörschienenachtergrund:"
+msgid "Transparent background"
+msgstr "Döörschienenachtergrund:"
 
 #: ../src/profile-preferences.glade.h:74
 msgid "_Update login records when command is launched"
diff --git a/po/ne.po b/po/ne.po
index 4fe16cc..d9a90ad 100644
--- a/po/ne.po
+++ b/po/ne.po
@@ -2398,8 +2398,8 @@ msgstr "सञ्झ्याल बन्द गर्नुहोस्"
 #~ msgid "_None (use solid color)"
 #~ msgstr "कुनै पनि होइन (एउटै रङ प्रयोग गर्नुहोस्)"
 
-#~ msgid "_Transparent background"
-#~ msgstr "पारदर्शी पृष्ठभूमि"
+msgid "Transparent background"
+msgstr "पारदर्शी पृष्ठभूमि"
 
 #~ msgid "_Use the system fixed width font"
 #~ msgstr "प्रणाली निश्चित गरिएको फन्ट चौडाइ प्रयोग गर्नुहोस्"
diff --git a/po/nl.po b/po/nl.po
index a51720b..111b032 100644
--- a/po/nl.po
+++ b/po/nl.po
@@ -2352,3 +2352,6 @@ msgstr "Venster sl_uiten"
 
 #~ msgid "Switch to Tab 12"
 #~ msgstr "Ga naar tab 12"
+
+msgid "Transparent background"
+msgstr "Transparante achtergrond"
diff --git a/po/nn.po b/po/nn.po
index 91cd6ab..9284459 100644
--- a/po/nn.po
+++ b/po/nn.po
@@ -1428,8 +1428,8 @@ msgid "_Text color:"
 msgstr "_Tekstfarge:"
 
 #: ../src/profile-preferences.glade.h:73
-msgid "_Transparent background"
-msgstr "_Gjennomskinleg bakgrunn"
+msgid "Transparent background"
+msgstr "Gjennomskinleg bakgrunn"
 
 #: ../src/profile-preferences.glade.h:74
 msgid "_Update login records when command is launched"
diff --git a/po/oc.po b/po/oc.po
index 5e7ca58..3bd9991 100644
--- a/po/oc.po
+++ b/po/oc.po
@@ -1285,8 +1285,8 @@ msgid "_Text color:"
 msgstr "Color del _tèxt :"
 
 #: ../src/profile-preferences.glade.h:78
-msgid "_Transparent background"
-msgstr "Fons _transparent"
+msgid "Transparent background"
+msgstr "Fons transparent"
 
 #: ../src/profile-preferences.glade.h:79
 msgid "_Underline color:"
diff --git a/po/or.po b/po/or.po
index ec1e6bf..218acd7 100644
--- a/po/or.po
+++ b/po/or.po
@@ -2705,8 +2705,8 @@ msgstr "ଶୀର୍ଷକ (_T):"
 #~ msgid "Background image _scrolls"
 #~ msgstr "ପୃଷ୍ଠଭୂମି ଚିତ୍ର ସ୍କ୍ରୋଲଗୁଡିକ (_s)"
 
-#~ msgid "_Transparent background"
-#~ msgstr "ସ୍ବଚ୍ଛ ପୃଷ୍ଠଭୂମି (_T)"
+msgid "Transparent background"
+msgstr "ସ୍ବଚ୍ଛ ପୃଷ୍ଠଭୂମି"
 
 #~ msgid "S_hade transparent or image background:"
 #~ msgstr "ଛାୟା ସ୍ବଚ୍ଛ କିମ୍ବା ଚିତ୍ର ପୃଷ୍ଠଭୂମି (_h):"
diff --git a/po/pa.po b/po/pa.po
index 9c95b66..5e5b8ba 100644
--- a/po/pa.po
+++ b/po/pa.po
@@ -3008,8 +3008,8 @@ msgstr "ਵਿੰਡੋ ਬੰਦ ਕਰੋ(_l)"
 #~ msgid "_Solid color"
 #~ msgstr "ਇੱਕ ਰੰਗ ਵਰਤੋਂ(_S)"
 
-#~ msgid "_Transparent background"
-#~ msgstr "ਪਾਰਦਰਸ਼ੀ ਬੈਕਗਰਾਊਂਡ(_T)"
+msgid "Transparent background"
+msgstr "ਪਾਰਦਰਸ਼ੀ ਬੈਕਗਰਾਊਂਡ"
 
 #~ msgid "S/Key Challenge Response"
 #~ msgstr "S/ਸਵਿੱਚ ਚੈਲੰਜ਼ ਜਵਾਬ"
diff --git a/po/pl.po b/po/pl.po
index deb91b7..f772171 100644
--- a/po/pl.po
+++ b/po/pl.po
@@ -2116,3 +2116,6 @@ msgid ""
 msgstr ""
 "Wartość między 0 a 100, gdzie 0 oznacza nieprzezroczystość, a 100 oznacza "
 "całkowitą przezroczystość."
+
+msgid "Transparent background"
+msgstr "Przezroczyste tło"
diff --git a/po/ps.po b/po/ps.po
index b1de52c..a16ac49 100644
--- a/po/ps.po
+++ b/po/ps.po
@@ -1052,8 +1052,8 @@ msgid "_Text color:"
 msgstr ":د ليکنې رنګ_"
 
 #: ../src/profile-preferences.glade.h:69
-msgid "_Transparent background"
-msgstr "روڼ شاليد_"
+msgid "Transparent background"
+msgstr "روڼ شاليد"
 
 #: ../src/profile-preferences.glade.h:70
 msgid "_Update login records when command is launched"
diff --git a/po/pt.po b/po/pt.po
index 68bb2dd..9078dcb 100644
--- a/po/pt.po
+++ b/po/pt.po
@@ -2948,8 +2948,8 @@ msgstr "_Fechar janela"
 #~ msgid "Background image _scrolls"
 #~ msgstr "Imagem de fundo _rola"
 
-#~ msgid "_Transparent background"
-#~ msgstr "Fundo _transparente"
+msgid "Transparent background"
+msgstr "Fundo transparente"
 
 #~ msgid "S_hade transparent or image background:"
 #~ msgstr "Transparente som_breado ou imagem de fundo:"
diff --git a/po/pt_BR.po b/po/pt_BR.po
index 8fac135..b79275c 100644
--- a/po/pt_BR.po
+++ b/po/pt_BR.po
@@ -2865,3 +2865,6 @@ msgstr "_Fechar janela"
 #~ "poderão usar. Essa é a paleta, na forma de uma lista de nomes de cores "
 #~ "separada por dois pontos. Os nomes de cores devem estar no formato "
 #~ "hexadecimal. Exemplo: \"#FF00FF\""
+
+msgid "Transparent background"
+msgstr "Fundo transparente"
diff --git a/po/ro.po b/po/ro.po
index 179dd77..f7fc7ae 100644
--- a/po/ro.po
+++ b/po/ro.po
@@ -1576,8 +1576,8 @@ msgid "_Text color:"
 msgstr "Culoare _text:"
 
 #: ../src/profile-preferences.glade.h:77
-msgid "_Transparent background"
-msgstr "Fundal _transparent"
+msgid "Transparent background"
+msgstr "Fundal transparent"
 
 #: ../src/profile-preferences.glade.h:78
 msgid "_Underline color:"
diff --git a/po/ru.po b/po/ru.po
index 01d1683..672ab01 100644
--- a/po/ru.po
+++ b/po/ru.po
@@ -2073,3 +2073,6 @@ msgstr ""
 #: ../src/terminal-window.c:3652
 msgid "C_lose Window"
 msgstr "_Закрыть окно"
+
+msgid "Transparent background"
+msgstr "Прозрачный фон"
diff --git a/po/rw.po b/po/rw.po
index 3f02231..b7fff4c 100644
--- a/po/rw.po
+++ b/po/rw.po
@@ -748,7 +748,7 @@ msgstr "Ibara ry'Inyandiko..."
 
 #: ../src/gnome-terminal.glade2.h:102
 #, fuzzy
-msgid "_Transparent background"
+msgid "Transparent background"
 msgstr "Mbuganyuma"
 
 #: ../src/gnome-terminal.glade2.h:103
diff --git a/po/si.po b/po/si.po
index 81dbf65..5cb0e5a 100644
--- a/po/si.po
+++ b/po/si.po
@@ -537,8 +537,8 @@ msgid "_Text color:"
 msgstr "පෙළ වර්‍ණ: (_T)"
 
 #: ../src/gnome-terminal.glade2.h:86
-msgid "_Transparent background"
-msgstr "විනිවිද පෙනෙන පසුබිම (_T)"
+msgid "Transparent background"
+msgstr "විනිවිද පෙනෙන පසුබිම"
 
 #: ../src/gnome-terminal.glade2.h:87
 msgid "_Update login records when command is launched"
diff --git a/po/sk.po b/po/sk.po
index 9bef0bf..52e4af2 100644
--- a/po/sk.po
+++ b/po/sk.po
@@ -2354,3 +2354,6 @@ msgstr "_Zavrieť okno"
 #~ "\n"
 #~ "Viac informácii o jednotlivých príkazoch získate pomocou „%s PRÍKAZ --"
 #~ "help“.\n"
+
+msgid "Transparent background"
+msgstr "Priehľadné pozadie"
diff --git a/po/sl.po b/po/sl.po
index 3a7ee4a..4f6ce0d 100644
--- a/po/sl.po
+++ b/po/sl.po
@@ -2316,3 +2316,6 @@ msgstr "_Zapri okno"
 
 #~ msgid "_Profile Preferences…"
 #~ msgstr "Možnosti _profila ..."
+
+msgid "Transparent background"
+msgstr "Prosojno ozadje"
diff --git a/po/sq.po b/po/sq.po
index e59c0b6..6fb4090 100644
--- a/po/sq.po
+++ b/po/sq.po
@@ -567,8 +567,8 @@ msgstr "Ngjyra e _tekstit:"
 
 # (pofilter) simplecaps: checks the capitalisation of two strings isn't wildly different
 #: ../src/gnome-terminal.glade2.h:85
-msgid "_Transparent background"
-msgstr "Sfond _Trasparent"
+msgid "Transparent background"
+msgstr "Sfond Trasparent"
 
 #: ../src/gnome-terminal.glade2.h:86
 msgid "_Update login records when command is launched"
diff --git a/po/sr.po b/po/sr.po
index fce0f63..22f129a 100644
--- a/po/sr.po
+++ b/po/sr.po
@@ -2230,3 +2230,6 @@ msgstr "_Затвори прозор"
 
 #~ msgid "Close Window"
 #~ msgstr "Затвори прозор"
+
+msgid "Transparent background"
+msgstr "Провидна позадина"
diff --git a/po/sr@latin.po b/po/sr@latin.po
index c82646c..55f6a0e 100644
--- a/po/sr@latin.po
+++ b/po/sr@latin.po
@@ -2230,3 +2230,6 @@ msgstr "_Zatvori prozor"
 
 #~ msgid "Close Window"
 #~ msgstr "Zatvori prozor"
+
+msgid "Transparent background"
+msgstr "Providna pozadina"
diff --git a/po/sv.po b/po/sv.po
index 8f64ba2..b0d6fcb 100644
--- a/po/sv.po
+++ b/po/sv.po
@@ -2080,5 +2080,8 @@ msgstr "Stän_g fönster"
 #~ msgid "Unknown completion request for \"%s\""
 #~ msgstr "Okänd kompletteringsbegäran för \"%s\""
 
+msgid "Transparent background"
+msgstr "Genomskinlig bakgrund"
+
 #~ msgid "Missing command"
 #~ msgstr "Kommando saknas"
diff --git a/po/ta.po b/po/ta.po
index 80aa2f6..61185b4 100644
--- a/po/ta.po
+++ b/po/ta.po
@@ -3028,8 +3028,8 @@ msgstr "_l சாளரத்தை மூடவும்"
 #~ msgid "_Solid color"
 #~ msgstr "(_S) ஒரே வண்ணம்"
 
-#~ msgid "_Transparent background"
-#~ msgstr "_T புலப்பாடு பின்னணி"
+msgid "Transparent background"
+msgstr "புலப்பாடு பின்னணி"
 
 #~ msgid "No such profile \"%s\", using default profile\n"
 #~ msgstr "\"%s\" என்ற வரியுரு கிடையாது, முன்னிருப்பு வரியுரு பயன்படுத்தப்படும்\n"
diff --git a/po/te.po b/po/te.po
index 000cda3..6dcf793 100644
--- a/po/te.po
+++ b/po/te.po
@@ -2898,8 +2898,8 @@ msgstr "కిటికీని మూసివేయి (_l)"
 #~ msgid "Background image _scrolls"
 #~ msgstr "నేపథ్యచిత్రము స్క్రాల్స్ (_s)"
 
-#~ msgid "_Transparent background"
-#~ msgstr "పారదర్శక నేపథ్యం (_T)"
+msgid "Transparent background"
+msgstr "పారదర్శక నేపథ్యం"
 
 #~ msgid "S_hade transparent or image background:"
 #~ msgstr "పారదర్శకంగా మారు లేదా చిత్రము బ్యాక్‌గ్రౌండ్ కు మారు(_h):"
diff --git a/po/th.po b/po/th.po
index be9b0cb..482907f 100644
--- a/po/th.po
+++ b/po/th.po
@@ -2616,8 +2616,8 @@ msgstr "ปิ_ดหน้าต่าง"
 #~ msgid "_Solid color"
 #~ msgstr "สี_ทึบ"
 
-#~ msgid "_Transparent background"
-#~ msgstr "พื้นหลังโปร่งแ_สง"
+msgid "Transparent background"
+msgstr "พื้นหลังโปร่งแสง"
 
 #~ msgid ""
 #~ "You already have a profile called “%s”. Do you want to create another "
diff --git a/po/tr.po b/po/tr.po
index 02a704a..78f26ba 100644
--- a/po/tr.po
+++ b/po/tr.po
@@ -1968,3 +1968,6 @@ msgstr "Hala bir süreç bu uçbirimde çalışıyor. Uçbirimi kapatmak onu son
 #: ../src/terminal-window.c:3652
 msgid "C_lose Window"
 msgstr "_Pencereyi Kapat"
+
+msgid "Transparent background"
+msgstr "Şeffaf arkaplan"
diff --git a/po/ug.po b/po/ug.po
index 1673bb3..e21e61e 100644
--- a/po/ug.po
+++ b/po/ug.po
@@ -2616,8 +2616,8 @@ msgstr "ماۋزۇ (_T):"
 #~ msgid "_Solid color"
 #~ msgstr "ساپ رەڭ(_S)"
 
-#~ msgid "_Transparent background"
-#~ msgstr "سۈزۈك تەگلىك(_T)"
+msgid "Transparent background"
+msgstr "سۈزۈك تەگلىك"
 
 #~ msgid ""
 #~ "You already have a profile called “%s”. Do you want to create another "
diff --git a/po/uk.po b/po/uk.po
index a8db018..414c413 100644
--- a/po/uk.po
+++ b/po/uk.po
@@ -2946,8 +2946,8 @@ msgstr "Закр_ити вікно"
 #~ msgid "_Solid color"
 #~ msgstr "_Суцільний колір"
 
-#~ msgid "_Transparent background"
-#~ msgstr "П_розоре тло"
+msgid "Transparent background"
+msgstr "Прозоре тло"
 
 #~ msgid "Switch to Tab 2"
 #~ msgstr "До вкладки 2"
diff --git a/po/vi.po b/po/vi.po
index e943917..87846ac 100644
--- a/po/vi.po
+++ b/po/vi.po
@@ -2671,3 +2671,6 @@ msgstr "Đón_g cửa sổ"
 #~ "Phím tắt để đặt lại thiết bị cuối. Dùng dạng chuỗi có cùng một khuôn dạng "
 #~ "với tập tin tài nguyên GTK+. Nếu bạn đặt tùy chọn là chuỗi “disabled” (bị "
 #~ "tắt), nghĩa là không có phím tắt cho hành động này."
+
+msgid "Transparent background"
+msgstr "Nền trong suốt"
diff --git a/po/wa.po b/po/wa.po
index 2856571..f068531 100644
--- a/po/wa.po
+++ b/po/wa.po
@@ -563,8 +563,8 @@ msgid "_Text color:"
 msgstr "Coleur pol _tecse:"
 
 #: ../src/gnome-terminal.glade2.h:86
-msgid "_Transparent background"
-msgstr "Fond k' on voet _houte"
+msgid "Transparent background"
+msgstr "Fond k' on voet houte"
 
 #: ../src/gnome-terminal.glade2.h:87
 msgid "_Update login records when command is launched"
diff --git a/po/xh.po b/po/xh.po
index e5981c6..7f9f804 100644
--- a/po/xh.po
+++ b/po/xh.po
@@ -620,8 +620,8 @@ msgid "_Text color:"
 msgstr "_Umbala wombhalo:"
 
 #: ../src/gnome-terminal.glade2.h:102
-msgid "_Transparent background"
-msgstr "_Okungasemva okucace gca"
+msgid "Transparent background"
+msgstr "Okungasemva okucace gca"
 
 #: ../src/gnome-terminal.glade2.h:103
 msgid "_Update login records when command is launched"
diff --git a/po/zh_CN.po b/po/zh_CN.po
index b18a9e7..287db04 100644
--- a/po/zh_CN.po
+++ b/po/zh_CN.po
@@ -2280,3 +2280,6 @@ msgstr "关闭窗口(_L)"
 
 #~ msgid "_Find..."
 #~ msgstr "查找(_F)..."
+
+msgid "Transparent background"
+msgstr "透明背景"
diff --git a/po/zh_HK.po b/po/zh_HK.po
index eb0ede7..aceb184 100644
--- a/po/zh_HK.po
+++ b/po/zh_HK.po
@@ -2376,3 +2376,6 @@ msgstr "關閉視窗(_L)"
 
 #~ msgid "Show session management options"
 #~ msgstr "顯示作業階段管理選項"
+
+msgid "Transparent background"
+msgstr "透明背景"
diff --git a/po/zh_TW.po b/po/zh_TW.po
index a32a539..f0674dc 100644
--- a/po/zh_TW.po
+++ b/po/zh_TW.po
@@ -2379,3 +2379,6 @@ msgstr "關閉視窗(_L)"
 
 #~ msgid "Show session management options"
 #~ msgstr "顯示作業階段管理選項"
+
+msgid "Transparent background"
+msgstr "透明背景"
-- 
2.1.0

